netapp_ontap.resources.storage_port API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.storage_port`

Copyright © 2020 NetApp Inc. All rights reserved.

## Retrieving storage port information

The storage port GET API retrieves all of the storage ports in the cluster.

## Examples

### 1) Retrieve a list of storage ports from the cluster

#### The following example shows the response with a list of storage ports in the cluster:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import StoragePort

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(StoragePort.get_collection()))

Try it out

    [
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0a",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0b",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0c",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0d",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0e",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0f",
            }
        ),
        StoragePort(
            {
                "node": {
                    "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                    "name": "node-1",
                    "_links": {
                        "self": {
                            "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                        }
                    },
                },
                "name": "0g",
            }
        ),
    ]

### 2) Retrieve a specific storage port from the cluster

#### The following example shows the response of the requested storage port. If there is no storage port with the requested node uuid and name, an error is returned.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import StoragePort

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = StoragePort(
            name="0a", **{"node.uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee"}
        )
        resource.get()
        print(resource)

Try it out

    StoragePort(
        {
            "cable": {
                "identifier": "500a0980066e2c01-500a098003633df0",
                "serial_number": "629230774",
                "length": "0.5m",
                "part_number": "112-00429+A0",
            },
            "node": {
                "uuid": "0530d6c1-8c6d-11e8-907f-00a0985a72ee",
                "name": "node-1",
                "_links": {
                    "self": {
                        "href": "/api/cluster/nodes/0530d6c1-8c6d-11e8-907f-00a0985a72ee"
                    }
                },
            },
            "state": "online",
            "name": "0a",
            "wwn": "500a098003633df0",
            "description": "SAS Host Adapter 0a (PMC-Sierra PM8001 rev. C)",
            "speed": 6.0,
        }
    )

## Classes

`class StoragePort (*args, **kwargs)`

  Allows interaction with StoragePort objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection(*args, connection: HostConnection = None, **kwargs) -> int`

    Retrieves a collection of storage ports.

    ### Related ONTAP commands

    - `storage port show`

    ### Learn more

    - `DOC /storage/ports`

    Fetch a count of all objects of this type from the host.

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def find(*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves a collection of storage ports.

    ### Related ONTAP commands

    - `storage port show`

    ### Learn more

    - `DOC /storage/ports`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection(*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> typing.Iterable`

    Retrieves a collection of storage ports.

    ### Related ONTAP commands

    - `storage port show`

    ### Learn more

    - `DOC /storage/ports`

    Fetch a list of all objects of this type from the host.

    This is a lazy fetch, making API calls only as necessary when the result of this call is iterated over. For instance, if max_records is set to 5, then iterating over the collection causes an API call to be sent to the server once for every 5 records. If the client stops iterating before getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves a specific storage port.

    ### Related ONTAP commands

    - `storage port show`

    ### Learn more

    - `DOC /storage/ports`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class StoragePortSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the StoragePort object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `board_name GET`

    The board_name field of the storage_port.

  `cable GET`

    The cable field of the storage_port.

  `description GET`

    The description field of the storage_port.

    Example: SAS Host Adapter 2a (PMC-Sierra PM8072 rev. C)

  `error GET`

    The error field of the storage_port.

  `mac_address GET`

    The mac_address field of the storage_port.

  `mode GET`

    Operational mode of a non-dedicated Ethernet port

    Valid choices:

    - network
    - storage
  `name GET`

    The name field of the storage_port.

    Example: 2a

  `node GET`

    The node field of the storage_port.

  `part_number GET`

    The part_number field of the storage_port.

    Example: 111-03801

  `serial_number GET`

    The serial_number field of the storage_port.

    Example: 7A2463CC45B

  `speed GET`

    Operational port speed in Gbps

    Example: 6.0

  `state GET`

    The state field of the storage_port.

    Valid choices:

    - online
    - offline
    - error
  `wwn GET`

    World Wide Name

    Example: 50000d1703544b80